==> dio-2.0.2.tar.gz: example/download.dart <==
import 'dart:io';
import 'package:dio/dio.dart';

// In this example we download a image and listen the downloading progress.
main() async {
  var dio = new Dio();

  (dio.httpClientAdapter as DefaultHttpClientAdapter).onHttpClientCreate =
      (HttpClient client) {
    client.idleTimeout = new Duration(seconds: 0);
  };

  // This is big file(about 200M)
  // var url = "http://download.dcloud.net.cn/HBuilder.9.0.2.macosx_64.dmg";

  // This is a image, about 4KB
  //var url = "https://flutter.io/assets/flutter-lockup-4cb0ee072ab312e59784d9fbf4fb7ad42688a7fdaea1270ccf6bbf4f34b7e03f.svg";
  var url =
      "https://cdn.jsdelivr.net/gh/flutterchina/flutter-in-action@1.0/docs/imgs/book.jpg";
  await download1(dio, url, "./example/book1.jpg");
  await download2(dio, url, "./example/book2.jpg");
}

Future download1(Dio dio, String url, String savePath) async {
  try {
    await dio.download(
      url,
      "./example/book.jpg",
      onReceiveProgress: showDownloadProgress,
    );
  } catch (e) {
    print(e);
  }
}

Future download2(Dio dio, String url, String savePath) async {
  try {
    Response response = await dio.get<List<int>>(
      url,
      onReceiveProgress: showDownloadProgress,
      //Received data with List<int>
      options: Options(responseType: ResponseType.bytes),
    );
    File file = new File(savePath);
    var raf = file.openSync(mode: FileMode.write);
    // response.data is List<int> type
    raf.writeFromSync(response.data);
    raf.close();
  } catch (e) {
    print(e);
  }
}

void showDownloadProgress(received, total) {
  if (total != -1) {
    print((received / total * 100).toStringAsFixed(0) + "%");
  }
}

==> dio-2.0.8.tar.gz: example/download.dart <==
import 'dart:io';
import 'package:dio/dio.dart';

// In this example we download a image and listen the downloading progress.
main() async {
  var dio = new Dio();
  dio.interceptors.add(LogInterceptor());
  // This is big file(about 200M)
  // var url = "http://download.dcloud.net.cn/HBuilder.9.0.2.macosx_64.dmg";

  var url =
      "https://cdn.jsdelivr.net/gh/flutterchina/flutter-in-action@1.0/docs/imgs/book.jpg";

 // var url = "https://www.baidu.com/img/bdlogo.gif";
  //await download1(dio, url, "./example/book1.jpg");
  await download2(dio, url, "./example/book2.jpg");
}

Future download1(Dio dio, String url, String savePath) async {
  try {
    await dio.download(
      url,
      savePath,
      onReceiveProgress: showDownloadProgress,
    );
  } catch (e) {
    print(e);
  }
}

Future download2(Dio dio, String url, String savePath) async {
  try {
    Response response = await dio.get(
      url,
      onReceiveProgress: showDownloadProgress,
      //Received data with List<int>
      options: Options(
        responseType: ResponseType.bytes,
        headers: {"range": "bytes=0-4999999999999"},
        followRedirects: false,
      ),
    );
    print(response.headers);
    File file = new File(savePath);
    var raf = file.openSync(mode: FileMode.write);
    // response.data is List<int> type
    raf.writeFromSync(response.data);
    await raf.close();
  } catch (e) {
    print(e);
  }
}

void showDownloadProgress(received, total) {
  if (total != -1) {
    print((received / total * 100).toStringAsFixed(0) + "%");
  }
}
